"""
    Copyright 2017 Inmanta

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Contact: code@inmanta.com
"""
import os

from inmanta.module import LocalFileRepo, RemoteRepo, gitprovider


def test_file_co(modules_dir, modules_repo):
    result = """name: mod6
license: Apache 2.0
version: '3.2'
"""
    module_yaml = gitprovider.get_file_for_version(os.path.join(modules_repo, "mod6"), "3.2", "module.yml")
    assert result == module_yaml


def test_local_repo_good(modules_dir, modules_repo):
    repo = LocalFileRepo(modules_repo)
    coroot = os.path.join(modules_dir, "clone_local_good")
    result = repo.clone("mod1", coroot)
    assert result
    assert os.path.exists(os.path.join(coroot, "mod1", "module.yml"))


def test_remote_repo_good(modules_dir, modules_repo):
    repo = RemoteRepo("https://github.com/rmccue/")
    coroot = os.path.join(modules_dir, "clone_remote_good")
    result = repo.clone("test-repository", coroot)
    assert result
    assert os.path.exists(os.path.join(coroot, "test-repository", "README"))


def test_local_repo_bad(modules_dir, modules_repo):
    repo = LocalFileRepo(modules_repo)
    coroot = os.path.join(modules_dir, "clone_local_good")
    result = repo.clone("thatotherthing", coroot)
    assert not result



"""
    Copyright 2020 Inmanta

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Contact: code@inmanta.com
"""
import json

import pytest


@pytest.mark.asyncio
async def test_extract_openapi_for_docs(server, client):
    result = await client.get_api_docs("openapi")
    assert result.code == 200
    content = result.result["data"]
    content["servers"][0]["url"] = "http://<inmanta-server-address>"
    content["info"]["description"] = "Back to <a href='./index.html'>Main documentation</a> for more information"
    json_content = json.dumps(content)
    with open("openapi.json", "w") as json_file:
        json_file.write(json_content)



"""
    Copyright 2018 Inmanta

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Contact: code@inmanta.com
"""

import inmanta.compiler as compiler
from inmanta.ast import ModuleNotFoundException


def test_issue_120_bad_import(snippetcompiler):
    snippetcompiler.setup_for_snippet("""import ip::ip""")
    try:
        compiler.do_compile()
        raise AssertionError("Should get exception")
    except ModuleNotFoundException as e:
        assert e.location.lnr == 1


def test_issue_120_bad_import_extra(snippetcompiler):
    snippetcompiler.setup_for_snippet("""import slorpf""")
    try:
        compiler.do_compile()
        raise AssertionError("Should get exception")
    except ModuleNotFoundException as e:
        assert e.location.lnr == 1


def test_1480_1767_invalid_repo(snippetcompiler_clean):
    snippetcompiler_clean.repo = "some_invalid_url"
    snippetcompiler_clean.setup_for_error(
        """

        """,
        "could not find module std (reported in import std (__internal__:1:1))"
        "\ncaused by:"
        "\n  Could not load module std"
        "\n  caused by:"
        "\n    inmanta.module.InvalidModuleException: could not locate module with name: std"
        "\n",
    )
